.. structurefunction documentation master file, created by
   sphinx-quickstart on Mon Nov  7 14:16:52 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Structure Functions for astronomy in Python
=============================================

.. mdinclude:: ../README.md

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   structurefunction
   example

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
